@@ -13,13 +13,13 @@ class CSVHandler:
         self.file = Path(filename).resolve()
         with self.file.open("w") as f:
             f.write("version, cycles, II, estimated_period, "
-                    "real_period, LUT, FF, DSP, BRAM, SRL\n")
+                    "real_period, LUT, FF, DSP, BRAM, SRL, Pipelined\n")
 
     def handle(self, record):
         syn = record["syn"]
         impl = record["impl"]
         with self.file.open('a') as f:
-            f.write("{}, {}, {}, {}, {}, {}, {}, {}, {}, {}\n".format(
+            f.write("{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}\n".format(
                 syn['Vivado_HLS_Version'],
                 syn['worst_case_latency'],
                 syn['II'],
@@ -29,19 +29,19 @@ class CSVHandler:
                 impl['FF'],
                 impl['DSP'],
                 impl['BRAM'],
-                impl['SRL'])
+                impl['SRL'],
+                syn['pipelined'])
             )
 
 
 def minimize_latency(exp_settings: vivado_exp.Experiment, handlers):
     logger = logging.getLogger("vrs_log")
-    handler = logging.FileHandler("{}.log".format(exp.name), "w")
+    handler = logging.FileHandler("{}.log".format(exp_settings.name), "w")
     handler.setLevel(logging.INFO)
     logger.addHandler(handler)
 
-    logger.info(f"Launching experiment {exp.name}")
+    logger.info(f"Launching experiment {exp_settings.name}")
     logger.info("Starting without latency constraint")
-    exp_type = vivado_exp.ExperienceType.SYNTHESIS if syn_only else vivado_exp.ExperienceType.IMPLEMENTATION
     ret = exp_settings.run_exp(suffix = "_base").get_results()
 
     constraint = float(exp_settings.clock_period)
@@ -56,7 +56,7 @@ def minimize_latency(exp_settings: vivado_exp.Experiment, handlers):
     timings = {cycles: timing}
     up = cycles
     cur_best_timing = timing
-    low = 1
+    low = 0
     while up > low + 1 and cycles != old_cycle:
         old_cycle = cycles
         if cur_best_timing > constraint:
