@@ -120,7 +120,7 @@ class Experiment:
                 before_del = None
                ):
         logger = self._logger
-        logger.info(f"Experiment: {exp_name}{suffix}")
+        logger.info(f"Experiment: {self._exp_name}{suffix}")
         comp = Path(self._comp_path).resolve()
         if not comp.exists():
             raise FileNotFoundError(f"Error when starting experiment: component file {comp} does not exist")
@@ -130,17 +130,18 @@ class Experiment:
             logger.debug("Adding pragma decoration")
 
             vivado_script = Path("vivado_script.tcl")
-            self._generate_script(vivado_script, self._exp_type)
+            self._generate_script(vivado_script)
             run_script(vivado_script)
 
-            vivado_hls_rpt = Path(
-                f"./vivado_hls_synthesis/solution/syn/report/{self._comp_name}_csynth.xml"
-            ).resolve()
+            vivado_hls_rpt = (Path() / "vivado_hls_synthesis" / "solution" /
+                            "syn" / "report" /
+                              f"{self._comp_name}_csynth.xml").resolve()
+
             self._csynth_res = vrpt.parse_syn_report(vivado_hls_rpt)
             if self._exp_type != ExperienceType.CSYNTH_ONLY:
-                vivado_report = Path(
-                    f"./vivado_hls_synthesis/solution/impl/report/{self._hdl.get_name()}/{self._comp_name}_export.xml"
-                ).resolve()
+                vivado_report = (Path() / "vivado_hls_synthesis" / "solution" /
+                                 "impl" / "report" / f"{self._hdl.get_name()}"
+                                 / f"{self._comp_name}_export.xml").resolve()
                 self._syn_impl_res = vrpt.parse_impl_report(vivado_report)
                 if before_del is not None:
                     befor_del()
