@@ -23,7 +23,7 @@ def create_project(file, project_name, filename, comp_name, includes, defines, s
     file.write("open_project {}\n".format(project_name))
     file.write("set_top {}\n".format(comp_name))
     includes_str = "" if includes is None else " ".join(
-        ["-I{}".format(s) for s in includes]
+        ["-I{}".format(str(s).replace("\\", "/")) for s in includes]
     )
     if defines:
         def format_def(define):
